@@ -1,10 +1,13 @@
 #!/usr/bin/env python3
-# Time-stamp: "2021-11-22 06:51:50 (ylab)"
+# Time-stamp: "2021-12-04 12:48:43 (ywatanabe)"
 
-from . import dsp, general, ml, plt, resource, stats
+from . import dsp, general, io, ml, plt, resource, stats
+from .general.debug import *
+
+# from .auto_ipdb import auto_ipdb
 
 __copyright__ = "Copyright (C) 2021 Yusuke Watanabe"
-__version__ = "0.1.2"
+__version__ = "0.2.2"
 __license__ = "GPL3.0"
 __author__ = "ywatanabe1989"
 __author_email__ = "ywata1989@gmail.com"
