@@ -1,6 +1,7 @@
 #!/usr/bin/env python3
 
 import numpy as np
+from scipy import stats
 
 
 def calc_partial_corrcoef(x, y, z):
@@ -22,6 +23,6 @@ def nocorrelation_test(x, y, z=None, alpha=0.05):
     df = n - 2
     # t = np.abs(np.array(r)) * np.sqrt((df) / (1 - np.array(r)**2))
     t = np.abs(r) * np.sqrt((df) / (1 - r ** 2))
-    t_alpha = stats.t.ppf(1 - alpha / 2, df)
+    # t_alpha = scipy.stats.t.ppf(1 - alpha / 2, df)
     p_value = 2 * (1 - stats.t.cdf(t, df))
     return r, t, p_value
